@@ -4,6 +4,7 @@
 from __future__ import absolute_import
 import base64
 import os
+import re
 import hmac
 
 from fxa import core
@@ -14,7 +15,7 @@ FXA_ERROR_ACCOUNT_EXISTS = 101
 
 def create_new_fxa_account(fxa_user_salt=None, account_server_url=None,
                            prefix="fxa", content_server_url=None):
-    if account_server_url and 'stage' in account_server_url:
+    if account_server_url and re.search('(dev)|(stage)', account_server_url):
         if not fxa_user_salt:
             fxa_user_salt = os.urandom(36)
         else:
@@ -35,7 +36,7 @@ def create_new_fxa_account(fxa_user_salt=None, account_server_url=None,
         finally:
             return email, password
     else:
-        message = ("You are not using stage (%s), make sure your FxA test "
-                   "account exists: %s" % (account_server_url,
-                                           content_server_url))
+        message = ("You are not using dev or stage (%s), make sure your FxA "
+                   "test account exists: %s" % (account_server_url,
+                                                content_server_url))
         raise ValueError(message)
